# ozi-core CHANGELOG
## 1.0.4 (2024-08-30)

## 1.0.3 (2024-08-30)


### 🐛 Fixed Bugs

* README text renders — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`60ca2f0`](https://github.com/OZI-Project/ozi-core/commit/60ca2f067ec1db949f288bda10f45531ef77f3f8))

## 1.0.2 (2024-08-30)


### 🐛 Fixed Bugs

* (ozi- missing): classifiers now render properly — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`c004a10`](https://github.com/OZI-Project/ozi-core/commit/c004a1014e8544fc2c8e5e50d427613afb324401))

## 1.0.1 (2024-08-30)


### 🐛 Fixed Bugs

* render METADATA for ``ozi- missing`` — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`932a611`](https://github.com/OZI-Project/ozi-core/commit/932a6117416c3837b49560f9e97209f80980a473))

* missing parses OZI 1.20 style dependencies — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`55a3941`](https://github.com/OZI-Project/ozi-core/commit/55a3941cfc26cb39358e133ed5f836a989ea3ab8))


### Performance


* perf: fix shadowed variable — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`be545e5`](https://github.com/OZI-Project/ozi-core/commit/be545e5fd09b7855e5d711696470552413abc7aa))

## 1.0.0 (2024-08-29)


### Breaking


* fix: correct release

BREAKING CHANGE: 1.0
([`eb199c1`](https://github.com/OZI-Project/ozi-core/commit/eb199c1e98e6d38363b51e4b8a86b866eb6e2a42))

## 0.4.0 (2024-08-29)


### Build


* (deps): ozi-templates~=2.10.1 — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`8d3db61`](https://github.com/OZI-Project/ozi-core/commit/8d3db61216deab6dd623a03ebeda754744474af2))

* (deps): update ozi-spec requirement from ~=0.8.1 to ~=0.9.1

Updates the requirements on [ozi-spec](https://github.com/OZI-Project/ozi-spec) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/ozi-spec/releases)
- [Changelog](https://github.com/OZI-Project/ozi-spec/blob/0.9.1/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-spec/compare/0.8.1...0.9.1)


updated-dependencies:
- dependency-name: ozi-spec
  dependency-type: direct:production
... — dependabot[bot] &lt;support@github.com&gt;
([`d570726`](https://github.com/OZI-Project/ozi-core/commit/d57072676e1f2ec2e995c3421183084208c9bffa))

* (deps): update ozi-templates requirement from ~=2.9.3 to ~=2.10.0


updated-dependencies:
- dependency-name: ozi-templates
  dependency-type: direct:production
... — dependabot[bot] &lt;support@github.com&gt;
([`a9548da`](https://github.com/OZI-Project/ozi-core/commit/a9548da914b3cef22eb5d1bea35aacead1ed61ea))


### Feature


* feat: OZI.build 1.3 ozi-templates 2.10 ozi-spec 0.9 — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`df99c91`](https://github.com/OZI-Project/ozi-core/commit/df99c9126bbf522e47a15cf4d6d96090390ab861))


### 🐛 Fixed Bugs

* Update pyproject.toml tox requirements install — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`c79cac8`](https://github.com/OZI-Project/ozi-core/commit/c79cac8aedd88ad0a97c9cc179743b93503de8de))

* remove requirements — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`7835209`](https://github.com/OZI-Project/ozi-core/commit/7835209bcf5c09c7171a2b5a531fcedf3fbb4f00))

* remove requires-python key — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`63aed2c`](https://github.com/OZI-Project/ozi-core/commit/63aed2c8808e936865cf24e8a3b063975041db88))

* update wrapfile — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`8470c88`](https://github.com/OZI-Project/ozi-core/commit/8470c885dd7a6aafa4e377c88f187b1b346fa8de))


### Performance


* perf: add ``# pragma: no cover`` to previously masked untested code — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`024c204`](https://github.com/OZI-Project/ozi-core/commit/024c2041f0c176088b76662b255cd782d99d1f80))

* perf: use main revision of OZI pre-1.20 — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`6d81567`](https://github.com/OZI-Project/ozi-core/commit/6d81567553c83234e27e658e8b4b97955273e1a8))

* perf: add install_dependencies postconf script — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`1c594c4`](https://github.com/OZI-Project/ozi-core/commit/1c594c450a732b3492aeff6762a05b135ffb4356))


### Unknown


* Update meson.build

BREAKING: 1.0 removes requirements.in — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`b06b8f2`](https://github.com/OZI-Project/ozi-core/commit/b06b8f2a1885b949bc9c11530c43679658c13eff))

* Update README

BREAKING: 1.0 — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`41ddc46`](https://github.com/OZI-Project/ozi-core/commit/41ddc467c5d5cf20c2e96cc314094055b1ba38d7))

* :bug: remove requires-python key — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`ef37bfa`](https://github.com/OZI-Project/ozi-core/commit/ef37bfa72bbc9747850f548bb307944a1ad6e66e))

## 0.3.1 (2024-08-23)


### Build


* (deps): update ozi-templates requirement from ~=2.9.0 to ~=2.9.3


updated-dependencies:
- dependency-name: ozi-templates
  dependency-type: direct:production
... — dependabot[bot] &lt;support@github.com&gt;
([`447823d`](https://github.com/OZI-Project/ozi-core/commit/447823da26b12b16de453e9b1609943bf925d69f))

* (deps): update ozi-spec requirement from ~=0.8.0 to ~=0.8.1

Updates the requirements on [ozi-spec](https://github.com/OZI-Project/ozi-spec) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/ozi-spec/releases)
- [Changelog](https://github.com/OZI-Project/ozi-spec/blob/main/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-spec/compare/0.8.0...0.8.1)


updated-dependencies:
- dependency-name: ozi-spec
  dependency-type: direct:production
... — dependabot[bot] &lt;support@github.com&gt;
([`f73eed2`](https://github.com/OZI-Project/ozi-core/commit/f73eed23b0f1e28a58fc8bdf0407cfa9acf4ebb9))

## 0.3.0 (2024-08-23)


### Build


* (pyproject.toml): asyncio_default_fixture_loop_scope = &#34;function&#34; — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`6ff7990`](https://github.com/OZI-Project/ozi-core/commit/6ff7990bff16e7c3c73556951eae1c8c8e68cd42))

* (deps): bump OZI-Project/checkpoint from 0.5.1 to 0.5.2

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 0.5.1 to 0.5.2.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/0.5.1...0.5.2)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`6a591dc`](https://github.com/OZI-Project/ozi-core/commit/6a591dc4dae5a62558034bf5e802fbe1fd8a8b52))

* (deps): bump OZI-Project/draft from 0.3.8 to 0.3.9

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.8 to 0.3.9.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/0.3.8...0.3.9)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`05a64a2`](https://github.com/OZI-Project/ozi-core/commit/05a64a27b40dd4f23eade8a44a38d0281cde344a))

* (deps): bump OZI-Project/release from 0.8.9 to 0.8.10

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.8.9 to 0.8.10.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/f4172eb60419c98b5cf18c89d78cde8b553f5d15...7edb07c74e124270a29b2cd5d32ce7c9fdfc0b22)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`f075e90`](https://github.com/OZI-Project/ozi-core/commit/f075e90baa283e316caa33942888577d60fe188f))

* (deps): bump OZI-Project/publish from 0.1.9 to 0.1.10

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.9 to 0.1.10.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/0.1.9...0.1.10)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`18068af`](https://github.com/OZI-Project/ozi-core/commit/18068af36cd2b5a396e1b30ca8084edc750497a3))

* (deps): update ozi-spec requirement from ~=0.6.1 to ~=0.8.0

Updates the requirements on [ozi-spec](https://github.com/OZI-Project/ozi-spec) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/ozi-spec/releases)
- [Changelog](https://github.com/OZI-Project/ozi-spec/blob/main/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-spec/compare/0.6.1...0.8.0)


updated-dependencies:
- dependency-name: ozi-spec
  dependency-type: direct:production
... — dependabot[bot] &lt;support@github.com&gt;
([`4e0495b`](https://github.com/OZI-Project/ozi-core/commit/4e0495b87a1572f570ee7cdb93a7fe0fe358cf18))

* (deps): update spdx-license-list requirement from ~=3.24 to ~=3.25

Updates the requirements on [spdx-license-list](https://github.com/JJMC89/spdx-license-list) to permit the latest version.
- [Release notes](https://github.com/JJMC89/spdx-license-list/releases)
- [Commits](https://github.com/JJMC89/spdx-license-list/compare/v3.24.0...v3.25.0)


updated-dependencies:
- dependency-name: spdx-license-list
  dependency-type: direct:production
... — dependabot[bot] &lt;support@github.com&gt;
([`073a707`](https://github.com/OZI-Project/ozi-core/commit/073a707fd7a89f8150f004d724cf3b2e27170d3f))


### Feature


* feat(deps): ozi-templates~=2.9.0 — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`54d06b7`](https://github.com/OZI-Project/ozi-core/commit/54d06b79482a85a25ba6e1cf9ff7ff5872c07edf))

* feat(deps): ozi-templates~=2.9.0 — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`db49f4e`](https://github.com/OZI-Project/ozi-core/commit/db49f4e3b1bb3ebf8b260d70cbe0cac121dd37f0))

* feat(deps): ozi-templates~=2.9.0 — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`e4150c1`](https://github.com/OZI-Project/ozi-core/commit/e4150c18273f41a599f06a8aad0a692f26271fe5))

## 0.2.4 (2024-08-18)


### 🐛 Fixed Bugs

* hide TAP version output during rewriter — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`8c654e4`](https://github.com/OZI-Project/ozi-core/commit/8c654e4f94691028961dfbdc33c52bc28c55fd03))

* (ozi-new interactive): enable uv working — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`8bd82b5`](https://github.com/OZI-Project/ozi-core/commit/8bd82b53ffa5bbf5ccffad8594c78d530e93cae2))


### Performance


* perf: move jinja2 import to typechecking block — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`72fef5d`](https://github.com/OZI-Project/ozi-core/commit/72fef5d5f882b41eb0a3a0909cff2edf4dec30d0))

## 0.2.3 (2024-08-18)


### Build


* (pyproject.toml): add uv dep — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`6bf4566`](https://github.com/OZI-Project/ozi-core/commit/6bf4566fc6595b1061ed6d03638f347e5f3016d2))


### Unknown


* :pushpin: ozi-templates~=2.8.2 — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`bf7c319`](https://github.com/OZI-Project/ozi-core/commit/bf7c31958817b1ef8761d480e53c6e4e65eb0ce0))

## 0.2.2 (2024-08-16)


### Performance


* perf: add ``--enable-uv`` argument expected in OZI spec 0.6 — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`a2fdd6b`](https://github.com/OZI-Project/ozi-core/commit/a2fdd6bbc4c6225ca90ee1851d4e5c1180ae7272))

## 0.2.1 (2024-08-16)


### Build


* (deps): update ozi-spec requirement from ~=0.5.10 to ~=0.6.1

Updates the requirements on [ozi-spec](https://github.com/OZI-Project/ozi-spec) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/ozi-spec/releases)
- [Changelog](https://github.com/OZI-Project/ozi-spec/blob/main/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-spec/compare/0.5.10...0.6.1)


updated-dependencies:
- dependency-name: ozi-spec
  dependency-type: direct:production
... — dependabot[bot] &lt;support@github.com&gt;
([`7e69af3`](https://github.com/OZI-Project/ozi-core/commit/7e69af3d275247695b1d2bb0ab6984c002ea6fdc))

* (deps): update ozi-templates requirement from ~=2.7.1 to ~=2.8.0


updated-dependencies:
- dependency-name: ozi-templates
  dependency-type: direct:production
... — dependabot[bot] &lt;support@github.com&gt;
([`137af6b`](https://github.com/OZI-Project/ozi-core/commit/137af6b59d728f5f462b82073f75e05b887ae015))

## 0.2.0 (2024-08-15)


### Feature


* feat: OZI-Templates 2.7

GitHub workflows are no longer hardened by default.
Wheels are now built with release 0.8 which can build extension wheels! — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`607b555`](https://github.com/OZI-Project/ozi-core/commit/607b555d1c638551853ef7b6372bdff919769f4d))


### Unknown


* :rotating_light: run black — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`bfe1b1b`](https://github.com/OZI-Project/ozi-core/commit/bfe1b1bf43c6dedf9b87ca74fe53b804e7f6ab34))

## 0.1.21 (2024-08-12)


### Performance


* perf: TAP-Producer~=1.0.4 — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`9ab7475`](https://github.com/OZI-Project/ozi-core/commit/9ab7475350b47e96de48efa7ccb40dd5a6fd3721))

## 0.1.20 (2024-08-12)


### Build


* (deps): bump OZI-Project/release from 0.8.5 to 0.8.7

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.8.5 to 0.8.7.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/0.8.5...0.8.7)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`8575198`](https://github.com/OZI-Project/ozi-core/commit/85751987f1493d01d43106563162a575bedb473d))

* (deps): update ozi-templates requirement from ~=2.6.1 to ~=2.6.4


updated-dependencies:
- dependency-name: ozi-templates
  dependency-type: direct:production
... — dependabot[bot] &lt;support@github.com&gt;
([`d3d5cb0`](https://github.com/OZI-Project/ozi-core/commit/d3d5cb05694abf0d50833b89781558579a92cc4d))


### 🐛 Fixed Bugs

* OZI-Project/release@0.8.9 — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`24a04fc`](https://github.com/OZI-Project/ozi-core/commit/24a04fc6443fc65cae87513faf49907ae42ea276))

* update release workflow — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`2be9889`](https://github.com/OZI-Project/ozi-core/commit/2be98899a9c31cd141fbe2b4d18782c0ce8f0caa))

## 0.1.19 (2024-08-12)


### 🐛 Fixed Bugs

* patch trigger — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`f175b58`](https://github.com/OZI-Project/ozi-core/commit/f175b58256581e6c8dd3f061eb4fecb7162833db))


### Performance


* perf: run lint
([`7bf2d0a`](https://github.com/OZI-Project/ozi-core/commit/7bf2d0abac0288f193c6dff1877d7caab02172df))


### Unknown


* :children_crossing: clean up diagnostic outputs — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`e2ae6bd`](https://github.com/OZI-Project/ozi-core/commit/e2ae6bdbadf9fa38c61bcd101dbf0e7f7240bfa3))

## 0.1.18 (2024-08-11)


### Build


* update ozi.yml allowed endpoints — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`3ee473d`](https://github.com/OZI-Project/ozi-core/commit/3ee473d61f7fc6c8246af013b5b7693d5b736587))

* (deps): bump OZI-Project/release from 0.7.4 to 0.8.5

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.7.4 to 0.8.5.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/0.7.4...0.8.5)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] &lt;support@github.com&gt;
([`d78bc4a`](https://github.com/OZI-Project/ozi-core/commit/d78bc4ab30aebaad18cca25531c7f1fe300100c4))


### 🐛 Fixed Bugs

* (ozi-new): set TAP.version before parsing args — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`4ce1d1c`](https://github.com/OZI-Project/ozi-core/commit/4ce1d1c055ac3b5c4ac852382325ae73453ac834))

## 0.1.17 (2024-08-07)


### Build


* (deps): update ozi-templates requirement from ~=2.5.8 to ~=2.6.1


updated-dependencies:
- dependency-name: ozi-templates
  dependency-type: direct:production
... — dependabot[bot] &lt;support@github.com&gt;
([`87a7da5`](https://github.com/OZI-Project/ozi-core/commit/87a7da50ea70f596e277469538dfb73113a1f4ef))

## 0.1.16 (2024-08-07)


### Build


* (deps): update tap-producer requirement from ~=0.2 to ~=1.0

Updates the requirements on [tap-producer](https://github.com/OZI-Project/TAP-Producer) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/TAP-Producer/releases)
- [Changelog](https://github.com/OZI-Project/TAP-Producer/blob/main/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/TAP-Producer/compare/0.2.0...1.0.0)


updated-dependencies:
- dependency-name: tap-producer
  dependency-type: direct:production
... — dependabot[bot] &lt;support@github.com&gt;
([`f122071`](https://github.com/OZI-Project/ozi-core/commit/f1220712a2763fde9d562fee76cd4eebdd7dcd87))

* (deps): update ozi-spec requirement from ~=0.5.8 to ~=0.5.9

Updates the requirements on [ozi-spec](https://github.com/OZI-Project/ozi-spec) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/ozi-spec/releases)
- [Changelog](https://github.com/OZI-Project/ozi-spec/blob/0.5.9/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-spec/compare/0.5.8...0.5.9)


updated-dependencies:
- dependency-name: ozi-spec
  dependency-type: direct:production
... — dependabot[bot] &lt;support@github.com&gt;
([`caae3de`](https://github.com/OZI-Project/ozi-core/commit/caae3de352cd02488393e5a88aeee45a1c824137))

* (deps): bump OZI-Project/checkpoint from 0.5.0 to 0.5.1

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 0.5.0 to 0.5.1.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/0.5.0...0.5.1)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`2b5c025`](https://github.com/OZI-Project/ozi-core/commit/2b5c02551ff2e40ad6fd48cb998819c0513b66dd))

* (deps): bump OZI-Project/release from 0.7.3 to 0.7.4

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.7.3 to 0.7.4.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/0.7.3...0.7.4)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`9a2de2f`](https://github.com/OZI-Project/ozi-core/commit/9a2de2f6274362809ac0c63f2c472f44eeec867d))

* (deps): bump step-security/harden-runner from 2.9.0 to 2.9.1

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.9.0 to 2.9.1.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/0d381219ddf674d61a7572ddd19d7941e271515c...5c7944e73c4c2a096b17a9cb74d65b6c2bbafbde)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`3365971`](https://github.com/OZI-Project/ozi-core/commit/3365971d93c97a895be9478e958729bed73378dc))

* (deps): bump OZI-Project/draft from 0.3.7 to 0.3.8

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.7 to 0.3.8.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/0.3.7...0.3.8)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`04aa4b1`](https://github.com/OZI-Project/ozi-core/commit/04aa4b15977ebc84bd6a98bbee98e42dd1f4594a))

* Update pyproject.toml:tool.semantic_release.commit_parser_options.patch_tags add  — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`553efa8`](https://github.com/OZI-Project/ozi-core/commit/553efa89fb9426e101a65d6a32d9fc39a48d15d8))

* (deps): update ozi-templates requirement from ~=2.5.6 to ~=2.5.8


updated-dependencies:
- dependency-name: ozi-templates
  dependency-type: direct:production
... — dependabot[bot] &lt;support@github.com&gt;
([`d937739`](https://github.com/OZI-Project/ozi-core/commit/d9377391f26d9a2234b16d6fc9895c2fdb29cccc))


### Performance


* perf: refactor interactive submodule — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`1d13d8e`](https://github.com/OZI-Project/ozi-core/commit/1d13d8e594ce2121f811462bed5bc4d05e7757ad))

## 0.1.15 (2024-07-30)


### Build


* (deps): update ozi-spec requirement from ~=0.5.7 to ~=0.5.8

Updates the requirements on [ozi-spec](https://github.com/OZI-Project/ozi-spec) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/ozi-spec/releases)
- [Changelog](https://github.com/OZI-Project/ozi-spec/blob/main/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/ozi-spec/compare/0.5.7...0.5.8)


updated-dependencies:
- dependency-name: ozi-spec
  dependency-type: direct:production
... — dependabot[bot] &lt;support@github.com&gt;
([`87a9703`](https://github.com/OZI-Project/ozi-core/commit/87a970368906f23468e0dce658f3b95d9fe4856d))


### Performance


* perf: Merge pull request #50 from OZI-Project/main

Release
([`7286ba3`](https://github.com/OZI-Project/ozi-core/commit/7286ba3a407aee2821624f78a8e45793c7147f58))

## 0.1.14 (2024-07-29)


### Performance


* perf: TAP-Producer~=0.2 — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`806e4e6`](https://github.com/OZI-Project/ozi-core/commit/806e4e690f036834aa5f2d79c9b2eb6c027f0462))

* perf: ozi-spec~=0.5.7 — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`25905f1`](https://github.com/OZI-Project/ozi-core/commit/25905f119deb214f69ece76753f56386f6715e77))

* perf: use TAP version 14 in ``ozi-new`` and ``ozi-fix`` — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`4e65ef5`](https://github.com/OZI-Project/ozi-core/commit/4e65ef546af4472125add85e2a4f987a38813526))

## 0.1.13 (2024-07-28)


### 🐛 Fixed Bugs

* gitpython~=3.1 — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`fd822c6`](https://github.com/OZI-Project/ozi-core/commit/fd822c640c0b469e71d46ea7f279a8b5cb42ae88))

## 0.1.12 (2024-07-25)


### 🐛 Fixed Bugs

* (requirements.in): ozi-spec~=0.5.7 — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`2aa4a87`](https://github.com/OZI-Project/ozi-core/commit/2aa4a87cedecb07bf0e68f0f19b9131269ddf2e7))

## 0.1.11 (2024-07-25)


### Build


* (deps): bump OZI-Project/publish from 0.1.8 to 0.1.9

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.8 to 0.1.9.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/0.1.8...0.1.9)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`452ad21`](https://github.com/OZI-Project/ozi-core/commit/452ad214b47668d8dd6112a2e51d1029b32624a6))

* (deps): bump OZI-Project/draft from 0.3.6 to 0.3.7

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.6 to 0.3.7.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/0.3.6...0.3.7)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`905c8dd`](https://github.com/OZI-Project/ozi-core/commit/905c8ddb2294e12d17db0ff8c8763c15746e6f5f))

## 0.1.10 (2024-07-22)


### Build


* (deps): update tap-producer requirement from ~=0.1.4 to ~=0.2.0

Updates the requirements on [tap-producer](https://github.com/OZI-Project/TAP-Producer) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/TAP-Producer/releases)
- [Changelog](https://github.com/OZI-Project/TAP-Producer/blob/main/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/TAP-Producer/compare/0.1.4...0.2.0)


updated-dependencies:
- dependency-name: tap-producer
  dependency-type: direct:production
... — dependabot[bot] &lt;support@github.com&gt;
([`31f6262`](https://github.com/OZI-Project/ozi-core/commit/31f626294d42088b072aa00704c14af2a4d06d39))

## 0.1.9 (2024-07-19)

## 0.1.8 (2024-07-19)

## 0.1.7 (2024-07-19)


### Build


* (deps): bump step-security/harden-runner from 2.8.0 to 2.9.0

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.8.0 to 2.9.0.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/v2.8.0...0d381219ddf674d61a7572ddd19d7941e271515c)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] &lt;support@github.com&gt;
([`bef7e1e`](https://github.com/OZI-Project/ozi-core/commit/bef7e1e2b0fcb9656f28171f316296a2834a5c54))

* (deps): update packaging requirement from ~=24.0 to ~=24.1

Updates the requirements on [packaging](https://github.com/pypa/packaging) to permit the latest version.
- [Release notes](https://github.com/pypa/packaging/releases)
- [Changelog](https://github.com/pypa/packaging/blob/main/CHANGELOG.rst)
- [Commits](https://github.com/pypa/packaging/compare/24.0...24.1)


updated-dependencies:
- dependency-name: packaging
  dependency-type: direct:production
... — dependabot[bot] &lt;support@github.com&gt;
([`13daef7`](https://github.com/OZI-Project/ozi-core/commit/13daef726f2bc916734e06bfb59d9940247ac1cd))

* (deps): bump OZI-Project/release from 0.6.5 to 0.7.3

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.6.5 to 0.7.3.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/0.6.5...0.7.3)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] &lt;support@github.com&gt;
([`a82c406`](https://github.com/OZI-Project/ozi-core/commit/a82c40631ffb94899420873b0cdf6c4914e0a73d))

* (deps): bump OZI-Project/publish from 0.1.7 to 0.1.8

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.7 to 0.1.8.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/0.1.7...0.1.8)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`152e647`](https://github.com/OZI-Project/ozi-core/commit/152e647612924699180b78034eceb99bad2798cf))

* (deps): bump OZI-Project/draft from 0.3.4 to 0.3.6

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.4 to 0.3.6.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/0.3.4...0.3.6)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`e60538c`](https://github.com/OZI-Project/ozi-core/commit/e60538c29ac5d1f618f259cf2d7c7629cd574759))

* (deps): bump OZI-Project/checkpoint from 0.4.2 to 0.5.0

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 0.4.2 to 0.5.0.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/0.4.2...0.5.0)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] &lt;support@github.com&gt;
([`a3c014a`](https://github.com/OZI-Project/ozi-core/commit/a3c014aa8c0d41374a1ebea87892433459a0e6b3))

* (deps): update tap-producer requirement from ~=0.1.1 to ~=0.1.4

Updates the requirements on [tap-producer](https://github.com/OZI-Project/TAP-Producer) to permit the latest version.
- [Release notes](https://github.com/OZI-Project/TAP-Producer/releases)
- [Changelog](https://github.com/OZI-Project/TAP-Producer/blob/0.1.4/CHANGELOG.md)
- [Commits](https://github.com/OZI-Project/TAP-Producer/compare/0.1.1...0.1.4)


updated-dependencies:
- dependency-name: tap-producer
  dependency-type: direct:production
... — dependabot[bot] &lt;support@github.com&gt;
([`aa61e25`](https://github.com/OZI-Project/ozi-core/commit/aa61e259ba90382d99881afd96ac425a2a42b47b))

* (deps): ozi-templates~=2.5.5 — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`d867913`](https://github.com/OZI-Project/ozi-core/commit/d8679132219753a12f47e57411a221d4a95d310b))


### 🐛 Fixed Bugs

* use ``ozi.version`` as key for wrapfile release revision selection — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`708552c`](https://github.com/OZI-Project/ozi-core/commit/708552cf3928b49393f8443c11659e8db71ba093))

* move remaining core functionality to package — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`0bb22a3`](https://github.com/OZI-Project/ozi-core/commit/0bb22a3efa9022386155a8cf3626e89429552a3a))

* ozi-core~=0.5.6 — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`485227f`](https://github.com/OZI-Project/ozi-core/commit/485227fc49d271ff8d946fc3cff33c4555c40f8e))

* correct changelog title — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`a01e5ce`](https://github.com/OZI-Project/ozi-core/commit/a01e5ceb1f51e084ceb4bc49bd15f08de8dd450c))

* correct ``templates/templates/*`` names to include ``.j2`` extension — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`ba9a68d`](https://github.com/OZI-Project/ozi-core/commit/ba9a68d5bfaba9513af8480fcc604527211de017))

* ozi-spec~=0.5.5

Implements sigstore-v3 workflows. — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`a2b2eac`](https://github.com/OZI-Project/ozi-core/commit/a2b2eacb4113d711077724c8b9ceced4071ac6f6))

* ozi-spec~=0.5.4 — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`dc31546`](https://github.com/OZI-Project/ozi-core/commit/dc31546e5e1714f823535edceb8ee70ba6cbb60e))


### Performance


* perf: Merge pull request #23 from OZI-Project/patch/sigstore-v3

Patch/sigstore v3
([`b63fd5b`](https://github.com/OZI-Project/ozi-core/commit/b63fd5b6de42e0f17b163f1fd9f1d3f74d20d7be))


### Unknown


* Update dependabot.yml — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`d0784c5`](https://github.com/OZI-Project/ozi-core/commit/d0784c5dfe89852a42a3ac2e04af6bce165ff536))

* Create dependabot.yml — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`e810ff4`](https://github.com/OZI-Project/ozi-core/commit/e810ff42fdec165967f31a39f9e14bbb6814c41e))

## 0.1.6 (2024-07-18)


### 🐛 Fixed Bugs

* OZI.build&gt;=0.0.27 — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`bc032f2`](https://github.com/OZI-Project/ozi-core/commit/bc032f214fc8cdfa51f6748b8f07461e301cf686))

## 0.1.5 (2024-07-18)


### 🐛 Fixed Bugs

* ozi-spec~=0.5.2 — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`bf4a290`](https://github.com/OZI-Project/ozi-core/commit/bf4a2903a4b7fd9d8d42570e6a3ca69c2ece1af9))

## 0.1.4 (2024-07-12)


### 🐛 Fixed Bugs

* ozi missing parser accepts target — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`0b6892c`](https://github.com/OZI-Project/ozi-core/commit/0b6892cbf9d8d1c174402746c419aa844e5cc3ab))


### Performance


* perf: clean up imports
([`f993ee4`](https://github.com/OZI-Project/ozi-core/commit/f993ee46db3d06b8c62d3163b0d384d53f2723ca))

## 0.1.3 (2024-07-12)


### Performance


* perf: run black — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`0728216`](https://github.com/OZI-Project/ozi-core/commit/0728216e7c48e8bd30872d56911328241121ea19))

## 0.1.2 (2024-07-12)

## 0.1.1 (2024-07-11)


### 🐛 Fixed Bugs

* comment scoring is ed
([`bdc4b60`](https://github.com/OZI-Project/ozi-core/commit/bdc4b60d2b90b01e412f1dbde12b6287b43da5cf))

*  comment line counting — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`d2d0192`](https://github.com/OZI-Project/ozi-core/commit/d2d019276f49bddae27fc752312ed9ed144f68a7))

* (ozi..parser): target as final argument — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`3afe42f`](https://github.com/OZI-Project/ozi-core/commit/3afe42f3bde8113f53b8f87aeb8cc49645375051))

## 0.1.0 (2024-07-11)

## 0.0.2 (2024-07-11)

## 0.0.1 (2024-07-11)


### Feature


* feat: remove ``print_version`` and add version arg to ``check_version`` — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`d88a200`](https://github.com/OZI-Project/ozi-core/commit/d88a2008163c244b56ffffdacb0727ca0d039f85))


### 🐛 Fixed Bugs

* override version arg for ``actions.info`` — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`dcb0b8f`](https://github.com/OZI-Project/ozi-core/commit/dcb0b8f8eeb6eacf05910eb8e461c0f1114ac5fb))

* (ozi_core..parser): target always last argument — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`52a135a`](https://github.com/OZI-Project/ozi-core/commit/52a135a3806af39bc30b5cf66461995fe6bd3af8))

* (ozi_core.new.parser): target now the last argument — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`92f8b86`](https://github.com/OZI-Project/ozi-core/commit/92f8b868f23778c835f522b64730819eaf48c97e))

* (requirements.in): add ``prompt-toolkit`` — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`f5ccb78`](https://github.com/OZI-Project/ozi-core/commit/f5ccb78f3e1f6165052b25635c85564219cc0315))

## 0.0.0 (2024-07-10)


### Unknown


* init
([`fc288f5`](https://github.com/OZI-Project/ozi-core/commit/fc288f56d4e0f31b3e4150ec4d6829df61ac117c))



## 0.0.0 (2024-07-09)

### :tada:

* :tada:: Initialized ozi-core with ``ozi-new``.

```sh
ozi-new project --name ozi-core --summary 'The OZI Project packaging core library.' --keywords OZI,mesonbuild --home-page https://www.oziproject.dev --author 'Eden Ross Duff MSc' --author-email help@oziproject.dev --license 'OSI Approved :: Apache Software License' --license-expression 'Apache-2.0 WITH LLVM-exception' --requires-dist 'pyparsing~=3.1' --requires-dist 'GitPython>=3' --requires-dist 'TAP-Producer~=0.1.1' --requires-dist 'meson[ninja]>=1.1.0' --requires-dist requests --requires-dist types-requests --requires-dist 'packaging~=24.0' --requires-dist spdx-license-list --requires-dist 'ozi-spec~=0.5' --requires-dist 'ozi-templates~=2.5.1'
```